# SnowML - Simple Neat Openweb ML Utils Framework

<p align="center">
    <img src="https://cdn-icons-png.flaticon.com/512/642/642012.png">
</p>

<p align="center" text>
<em>Designed by Data Scientists</em>
</p>

<p align="center" text>
<em>For Data Scientists</em>
</p>

## Setup & Installation
```bash
# Create the python environment
python3 -m venv venv

# Update pip
pip3 install --upgrade pip

# Install SnowML
pip3 install SnowML
```